//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Files/DatafilesSet.h
//! @brief     Defines class DatafilesSet.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H
#define BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H

#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/Model/Files/DatafilesCleaner.h"
#include "GUI/Model/Type/SetWithModel.h"
#include <QXmlStreamWriter>

class DataItem;
class MessageService;

//! The DatafilesSet class is a model to store all imported DatafileItem's.
class DatafilesSet : public SetWithModel<DatafileItem> {
public:
    DatafilesSet();
    virtual ~DatafilesSet();

    void readFrom(QXmlStreamReader* r);
    void readDatafiles(const QString& projectDir, MessageService* messageService);

    void writeTo(QXmlStreamWriter* w) const;
    void writeDatafiles(const QString& projectDir) const;

private:
    QVector<DataItem*> dataItems() const;

    mutable DatafilesCleaner dataFilesCleaner;
};

#endif // BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H
