//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Widget/SetView.cpp
//! @brief     Implements class SetView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Widget/SetView.h"
#include "GUI/Model/Type/SetWithModel.h"
#include "GUI/View/Widget/ListItemDelegate.h"

SetView::SetView(AbstractSetModel* set, int minimum_width, QSizePolicy policy)
{
    setMinimumWidth(minimum_width);
    setSizePolicy(policy);
    setSelectionMode(QAbstractItemView::NoSelection);
    setItemDelegate(new ListItemDelegate(this));
    setModel(set->model());

    connect(this, &QListView::clicked, [this, set](const QModelIndex& qi) {
        set->setCurrentIndex(qi.row());
        this->setCurrentIndex({}); // keep "current" invalid, hence invisible
    });
    setCurrentIndex({}); // make "current" invalid, hence invisible
}
